@@ -37,7 +37,7 @@ function(xdata.s1, ydata.s1 = NULL, zdata, xdata.s2 = NULL, ydata.s2,
   # Indices for coding convenience
   no.dv.t <- (m.s1 + s.s1 + p + 1 + m.s2 + s.s2 + 1) 
   id.v.s1 <- 1:m.s1
-  id.u.s1 <- if(is.null(ydata.s1)) 0 else id.v.s1 + m.s1
+  id.u.s1 <- if(is.null(ydata.s1)) NULL else (m.s1 + 1):(m.s1 + s.s1)
   id.p    <- (m.s1 + s.s1 + 1):(m.s1 + s.s1 + p)
   id.w.s1 <-  m.s1 + s.s1 + p + 1
   id.v.s2 <- if(is.null(xdata.s2)) 0 else (m.s1 + s.s1 + p + 2):(m.s1 + s.s1 + p + 1 + m.s2)
